==> cfg_e5_2_22_w5_2_46.tar: cfg_e/js/js/sections/sectionsList.js <==
function selectedTypeGuardZone(model, typeLW, param, zone, delay, who, indexZone, sections) {
  /*  model  - Радио устройство;
        typeLW - Класс зоны (5:Охранный, 4:Пожарный, 2:Техно);
        param  - Тип зоны;
        zone   - Номер зоны (1:основная, 2:Доп);
        delay  - Задержка;
        who    - Откуда вызвана функция (радиоканал, разделы);
        indexZone - Номер зоны устройства (1,2 - Основная или дополнительная);
        sections - Номер зоны в которую добавляем устройство (Если null до добавляем радиоканальное устройство. Выводим датчики управления если - null)
    */


  let str = "";
  let type;
  let thisExt;
  let modelIntegral = model.slice(0, 8)
  type = param;
  if (param == '') {
    type = 'noused'
  }
  delay = +delay;
  if (+model < 100) {
    model = RS485_LIST[model];
    thisExt = true;
  }

  if (typeLW === "1") {
    type = "noused";
  }

  str += "<select style='width:300px' class='";
  if (who === "ext") {
    str += "typeNext";
  }

  str += "' name='modal_r_device_zone_delay_" + zone + "' id='modal_r_device_zone_type_";
  if (who === "sections") {
    // Меняем идентификатор если вызвали из вкладки Разделы/зоны
    str += "S_";
  } else if (who === "ext") {
    str += "E_";
  } else {
  }
  str += zone;
  str += "'  onchange='modal_r_device_setTypeZone(this)'";

  if (type == 'noused' && modelIntegral == 'integral' && who == 'sections') {
    str += "disabled ";
  }
  str += ">"
  // ▼ Не используется ▼
  str += '<option name="0" value="noused" title="' + KEY_DESCRIPTION["s_noused"].title + '"';
  if (type === "noused") {
    str += " selected ";
  }
  str += ">";
  str += "Не используется</option>";

  // ▼ Охранная ▼
  str += '<option class="guardS" name="5" value="5_0" title="' + KEY_DESCRIPTION["s_guard"].title + '"';
  if (type === '0' && delay === 0) {
    str += " selected ";
  }
  str += ">";
  str += "Охранная</option>";

  // ▼ Охранная с задержкой ▼
  //if (+indexZone === 2 || model !== '15230' && model !== '15231' && model !== '15830') { Фильтр типа зоны для Юпитер 5230 5231
  if (+indexZone === 2 || model !== "15830") {
    str += '<option class="guardS" name="5" value="5_4" title="' + KEY_DESCRIPTION["s_guardDelay"].title + '"';
    if (type === '4' && typeLW === "5") {
      str += " selected ";
    }
    str += ">";
    str += "Охранная с задержкой (вход/выход)</option>";
  }

  // ▼ Проходная ▼
  if (+indexZone === 2 || model !== "15830") {
    str += '<option class="guardS" name="5" value="5_2"  title="' + KEY_DESCRIPTION["s_prohod"].title + '"';
    if (type === '2' && typeLW === "5") {
      str += " selected ";
    }
    str += ">";
    str += "Охранная с зад. на выход (Проходная)</option>";
  }

  // ▼ Охр. с фикс. зад. ▼
  //if (+indexZone === 2 && delay !== 0 || model !== '15230' && model !== '15231' && model !== '15830') {  Фильтр типа зоны для Юпитер 5230 5231
  if ((+indexZone === 2 && delay !== 0) || model !== "15830") {
    str += '<option class="guardS" name="5" value="5_0D" title="' + KEY_DESCRIPTION["s_guardFixDelay"].title + '"';
    if (type === '0' && delay !== 0 && typeLW === "5") {
      str += " selected ";
    }
    str += ">";
    str += "Охранная с фикс. зад.(вход/выход)</option>";
  }

  // ▼ Охр. с контр. взлома ▼
  if (model !== '15130' && model !== '15230' && model !== '15231' && model !== '15830') {
    str += '<option class="guardS" name="5" value="5_8" ';
    if (type === '8' && typeLW === "5") {
      str += " selected ";
    }
    str += ">";
    str += "Охранная с контр. взлома</option>";
  }
  // ▼ Проход. с контр. взлома ▼
  if (model !== '15130' && model !== '15230' && model !== '15231' && model !== '15830') {
    str += '<option class="guardS" name="5" value="5_10" ';
    if (type === '10' && typeLW === "5") {
      str += " selected ";
    }
    str += ">";
    str += "Охранная с зад.на вых.(Проход.) с контр. взл.</option>";
  }

  // ▼ КТС ▼
  if (+indexZone === 2 || (model !== "15130" && model !== "15230" && model !== "15231" && model !== "15830")) {
    str += '<option class="guardS" name="5" value="5_1" title="' + KEY_DESCRIPTION["s_KTS"].title + '"';
    if (type === '1' && typeLW === "5") {
      str += " selected ";
    }
    str += ">";
    str += "Тревожная (КТС)</option>";
  }

  // ▼ ПАТРУЛЬ ▼
  if (+indexZone === 2 || (model !== "15130" && model !== "15230" && model !== "15231" && model !== "15830")) {
    str += '<option class="guardS" name="5" value="5_32" title="' + KEY_DESCRIPTION["s_Patrul"].title + '"';
    if (type === '32' && typeLW === "5") {
      str += " selected ";
    }
    str += ">";
    str += "ПАТРУЛЬ</option>";
  }

  // ▼ ПОЖАРНАЯ ▼
  if (+indexZone === 2 || (model !== "15130" && model !== "15230" && model !== "15231" && model !== "15830")) {
    //if (!thisExt) {
    /*  if (DEVICEMODEL.indexOf("208") != -1 || DEVICEMODEL.slice(0, 5).indexOf("202") != -1) {
       //console.log("Отключен пожарный тип для РКПС");
       // СПЕШЛ ФО ВАДИМ 14.01.2021
     } else { */
    str += '<option class="fireS" name="4" value="4_2" title="' + KEY_DESCRIPTION["s_Fire"].title + '"';
    if (type === '2' && typeLW === "4") {
      str += " selected ";
    }
    str += ">";
    str += "ПОЖАРНАЯ</option>";
  }
  //}
  //}

  // ▼ ГАЗ ▼
  if (+indexZone === 2 || (model !== "15130" && model !== "15230" && model !== "15231" && model !== "15830")) {
    //if (!thisExt) {
    str += '<option class="techS" name="2" value="2_2" title="' + KEY_DESCRIPTION["s_Gaz"].title + '"';
    if (type === '2' && typeLW === "2") {
      str += " selected ";
    } else if (type === '3' && typeLW === "2") {
      str += " selected ";
    }
    str += ">";
    str += "ГАЗ</option>";
    //}
  }

  // ▼ ВОДА ▼
  if (+indexZone === 2 || (model !== "15130" && model !== "15230" && model !== "15231" && model !== "15830")) {
    //if (!thisExt) {
    str += '<option class="techS" name="2" value="2_5" title="' + KEY_DESCRIPTION["s_Water"].title + '"';
    if (type === '4' && typeLW === "2") {
      str += " selected ";
    } else if (type === 5 && typeLW === "2") {
      str += " selected ";
    }
    str += ">";
    str += "ВОДА</option>";
    //}
  }

  // ▼ УПРАВЛЕНИЕ ▼
  if (+indexZone === 2 || (model !== "15130" && model !== "15230" && model !== "15231" && model !== "15830")) {
    // if (!thisExt) {
    str += '<option class="techS" name="2" value="3_0" title="' + KEY_DESCRIPTION["s_Water"].title + '"';
    if (type === '0' && typeLW === "3") {
      str += " selected ";
    }
    str += ">";
    str += "УПРАВЛЕНИЕ</option>";
    //}
  }

  // ▼ ПОЛЬЗОВАТЕЛЬСКАЯ ▼
  if (+indexZone === 2 || (model !== "15130" && model !== "15230" && model !== "15231" && model !== "15830")) {
    //if (!thisExt) {
    str += '<option class="techS" name="2" value="2_8" title=""';
    if (type === '8' && typeLW === "2") {
      str += " selected ";
    } else if (type === 9 && typeLW === "2") {
      str += " selected ";
    }
    str += ">";
    str += "ПОЛЬЗОВАТЕЛЬСКАЯ</option>";
    //}
  }

  str += "</select>";

  return str;
}

==> cfg_e5_2_25_w5_2_51.tar: cfg_e/js/js/sections/sectionsList.js <==
function selectedTypeGuardZone(model, typeLW, param, zone, delay, who, indexZone, sections) {
  /*  model  - Радио устройство;
        typeLW - Класс зоны (5:Охранный, 4:Пожарный, 2:Техно);
        param  - Тип зоны;
        zone   - Номер зоны (1:основная, 2:Доп);
        delay  - Задержка;
        who    - Откуда вызвана функция (радиоканал, разделы);
        indexZone - Номер зоны устройства (1,2 - Основная или дополнительная);
        sections - Номер зоны в которую добавляем устройство (Если null до добавляем радиоканальное устройство. Выводим датчики управления если - null)
    */


  let str = "";
  let type;
  let thisExt;
  let modelIntegral = model.slice(0, 8)
  type = param;
  if (param == '') {
    type = 'noused'
  }
  delay = +delay;
  if (+model < 100) {
    model = RS485_LIST[model];
    thisExt = true;
  }

  if (typeLW === "1") {
    type = "noused";
  }

  str += "<select style='width:300px' class='";
  if (who === "ext") {
    str += "typeNext";
  }

  str += "' name='modal_r_device_zone_delay_" + zone + "' id='modal_r_device_zone_type_";
  if (who === "sections") {
    // Меняем идентификатор если вызвали из вкладки Разделы/зоны
    str += "S_";
  } else if (who === "ext") {
    str += "E_";
  } else {
  }
  str += zone;
  str += "'  onchange='modal_r_device_setTypeZone(this)'";

  if (type == 'noused' && modelIntegral == 'integral' && who == 'sections') {
    str += "disabled ";
  }
  str += ">"
  // ▼ Не используется ▼
  str += '<option name="0" value="noused" title="' + KEY_DESCRIPTION["s_noused"].title + '"';
  if (type === "noused") {
    str += " selected ";
  }
  str += ">";
  str += "Не используется</option>";

  // ▼ Охранная ▼
  str += '<option class="guardS" name="5" value="5_0" title="' + KEY_DESCRIPTION["s_guard"].title + '"';
  if (type === '0' && delay === 0) {
    str += " selected ";
  }
  str += ">";
  str += "Охранная</option>";

  // ▼ Охранная с задержкой ▼
  //if (+indexZone === 2 || model !== '15230' && model !== '15231' && model !== '15830') { Фильтр типа зоны для Юпитер 5230 5231
  if (+indexZone === 2 || model !== "15830") {
    str += '<option class="guardS" name="5" value="5_4" title="' + KEY_DESCRIPTION["s_guardDelay"].title + '"';
    if (type === '4' && typeLW === "5") {
      str += " selected ";
    }
    str += ">";
    str += "Охранная с задержкой (вход/выход)</option>";
  }

  // ▼ Проходная ▼
  if (+indexZone === 2 || model !== "15830") {
    str += '<option class="guardS" name="5" value="5_2"  title="' + KEY_DESCRIPTION["s_prohod"].title + '"';
    if (type === '2' && typeLW === "5") {
      str += " selected ";
    }
    str += ">";
    str += "Охранная с зад. на выход (Проходная)</option>";
  }

  // ▼ Охр. с фикс. зад. ▼
  //if (+indexZone === 2 && delay !== 0 || model !== '15230' && model !== '15231' && model !== '15830') {  Фильтр типа зоны для Юпитер 5230 5231
  if ((+indexZone === 2 && delay !== 0) || model !== "15830") {
    str += '<option class="guardS" name="5" value="5_0D" title="' + KEY_DESCRIPTION["s_guardFixDelay"].title + '"';
    if (type === '0' && delay !== 0 && typeLW === "5") {
      str += " selected ";
    }
    str += ">";
    str += "Охранная с фикс. зад.(вход/выход)</option>";
  }

  // ▼ Охр. с контр. взлома ▼
  if (model !== '15130' && model !== '15230' && model !== '15231' && model !== '15830') {
    str += '<option class="guardS" name="5" value="5_8" ';
    if (type === '8' && typeLW === "5") {
      str += " selected ";
    }
    str += ">";
    str += "Охранная с контр. взлома</option>";
  }
  // ▼ Проход. с контр. взлома ▼
  if (model !== '15130' && model !== '15230' && model !== '15231' && model !== '15830') {
    str += '<option class="guardS" name="5" value="5_10" ';
    if (type === '10' && typeLW === "5") {
      str += " selected ";
    }
    str += ">";
    str += "Охранная с зад.на вых.(Проход.) с контр. взл.</option>";
  }

  // ▼ КТС ▼
  if (+indexZone === 2 || (model !== "15130" && model !== "15230" && model !== "15231" && model !== "15830")) {
    str += '<option class="guardS" name="5" value="5_1" title="' + KEY_DESCRIPTION["s_KTS"].title + '"';
    if (type === '1' && typeLW === "5") {
      str += " selected ";
    }
    str += ">";
    str += "Тревожная (КТС)</option>";
  }

  // ▼ ПАТРУЛЬ ▼
  if (+indexZone === 2 || (model !== "15130" && model !== "15230" && model !== "15231" && model !== "15830")) {
    str += '<option class="guardS" name="5" value="5_32" title="' + KEY_DESCRIPTION["s_Patrul"].title + '"';
    if (type === '32' && typeLW === "5") {
      str += " selected ";
    }
    str += ">";
    str += "ПАТРУЛЬ</option>";
  }

  // ▼ ПОЖАРНАЯ ▼
  if (+indexZone === 2 || (model !== "15130" && model !== "15230" && model !== "15231" && model !== "15830")) {
    //if (!thisExt) {
    /*  if (DEVICEMODEL.indexOf("208") != -1 || DEVICEMODEL.slice(0, 5).indexOf("202") != -1) {
       //console.log("Отключен пожарный тип для РКПС");
       // СПЕШЛ ФО ВАДИМ 14.01.2021
     } else { */
    str += '<option class="fireS" name="4" value="4_2" title="' + KEY_DESCRIPTION["s_Fire"].title + '"';
    if (type === '2' && typeLW === "4") {
      str += " selected ";
    }
    str += ">";
    str += "ПОЖАРНАЯ</option>";
  }
  //}
  //}

  // ▼ ГАЗ ▼
  if (+indexZone === 2 || (model !== "15130" && model !== "15230" && model !== "15231" && model !== "15830")) {
    //if (!thisExt) {
    str += '<option class="techS" name="2" value="2_2" title="' + KEY_DESCRIPTION["s_Gaz"].title + '"';
    if (type === '2' && typeLW === "2") {
      str += " selected ";
    } else if (type === '3' && typeLW === "2") {
      str += " selected ";
    }
    str += ">";
    str += "ГАЗ</option>";
    //}
  }

  // ▼ ВОДА ▼
  if (+indexZone === 2 || (model !== "15130" && model !== "15230" && model !== "15231" && model !== "15830")) {
    //if (!thisExt) {
    str += '<option class="techS" name="2" value="2_5" title="' + KEY_DESCRIPTION["s_Water"].title + '"';
    if (type === '4' && typeLW === "2") {
      str += " selected ";
    } else if (type === "5" && typeLW === "2") {
      str += " selected ";
    }
    str += ">";
    str += "ВОДА</option>";
    //}
  }

  // ▼ УПРАВЛЕНИЕ ▼
  if (+indexZone === 2 || (model !== "15130" && model !== "15230" && model !== "15231" && model !== "15830")) {
    // if (!thisExt) {
    str += '<option class="techS" name="2" value="3_0" title="' + KEY_DESCRIPTION["s_Water"].title + '"';
    if (type === '0' && typeLW === "3") {
      str += " selected ";
    }
    str += ">";
    str += "УПРАВЛЕНИЕ</option>";
    //}
  }

  // ▼ ПОЛЬЗОВАТЕЛЬСКАЯ ▼
  if (+indexZone === 2 || (model !== "15130" && model !== "15230" && model !== "15231" && model !== "15830")) {
    //if (!thisExt) {
    str += '<option class="techS" name="2" value="2_8" title=""';
    if (type === '8' && typeLW === "2") {
      str += " selected ";
    } else if (type === "9" && typeLW === "2") {
      str += " selected ";
    }
    str += ">";
    str += "ПОЛЬЗОВАТЕЛЬСКАЯ</option>";
    //}
  }

  str += "</select>";

  return str;
}
